Open-CRAVAT is a python package that performs genomic variant interpretation including variant impact, annotation,
 and scoring.  It has a modular architecture with a wide variety of analysis modules that are developed both by 
 the CRAVAT team and the broader variant analysis community. Open-CRAVAT is a product of the `Karchin Lab`_ 
 at Johns Hopkins University in collaboration with `In Silico Solutions`_ with funding provided by the National 
 Cancer Institute's `ITCR`_ program.

.. _Karchin Lab: http://karchinlab.org
.. _In Silico Solutions: http://insilico.us.com
.. _ITCR: https://itcr.cancer.gov

Please see: `Open-CRAVAT Docs`_ for installation instructions and software documentation.

.. _Open-CRAVAT Docs: https://github.com/KarchinLab/open-cravat/wiki